==> cms-db_v0.9.tar.gz: admin/restorepage2.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('recyclebin');
?>
<?php
include('../functions_url.inc.php');

function getID() {
   if ($_GET['sec'] == 'root') {
	  $home_pfad = '../data/pages/';
   } else {
	  $home_pfad = get_filename_from_url($_GET['sec']);
	  $home_pfad = '../data/pages'.substr($home_pfad, 0, strrpos($home_pfad, '/'));
   }
   $i = 1;

   $dh = opendir($home_pfad);
   while ($datei = readdir($dh)) {
      if($datei !== ""   &&
         $datei !== "."  &&
         $datei !== "..") {
            $i++;
      }
   }
   if ($i < 10) {
      $i = '0'.$i;
   }
   return $i;
}

$file = '../data/recyclebin/pages/'.$_GET['page'];
if ($_GET['sec'] == 'root') {
	$sec = '../data/pages/';
} else {
	$sec = get_filename_from_url($_GET['sec']);
	$sec = '../data/pages'.substr($sec, 0, strrpos($sec, '/'));
}
$newfile = getID().','.$_GET['page'];

if (file_exists($sec.'/'.$newfile)) {
	$timestamp = time();
	$newfile = $newfile.'-'.$timestamp;
}

if (!mkdir($sec.'/'.$newfile)) {
	include('error.inc.php');
	throw_error(locale('desc_error-restore',true), 'recyclebin.php?'.SID.csrf_protection_get());
}
$newfile = $newfile.'/01,Home';
if (!copy($file, $sec.'/'.$newfile)) {
	include('error.inc.php');
	throw_error(locale('desc_error-restore',true), 'recyclebin.php?'.SID.csrf_protection_get());
}
if (!unlink($file)) {
	include('error.inc.php');
	throw_error(locale('desc_error-restore',true), 'recyclebin.php?'.SID.csrf_protection_get());
}
include('cache.inc.php');
clear_cache('pages');
include('urlindex.inc.php');
generate_urlindex();
header('Location:pages.php?'.SID.csrf_protection_get());
?>

==> cms-db_v0.9.3.tar.gz: admin/restorepage2.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');
checkuser('pages');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('recyclebin');
?>
<?php
include('../functions_url.inc.php');

function getID() {
   if ($_GET['sec'] == 'root') {
	  $home_pfad = '../data/pages/';
   } else {
	  $home_pfad = get_filename_from_url($_GET['sec']);
	  $home_pfad = '../data/pages'.substr($home_pfad, 0, strrpos($home_pfad, '/'));
   }
   $i = 1;

   $dh = opendir($home_pfad);
   while ($datei = readdir($dh)) {
      if($datei !== ""   &&
         $datei !== "."  &&
         $datei !== "..") {
            $i++;
      }
   }
   if ($i < 10) {
      $i = '0'.$i;
   }
   return $i;
}

$file = '../data/recyclebin/pages/'.$_GET['page'];
if ($_GET['sec'] == 'root') {
	$sec = '../data/pages/';
} else {
	$sec = get_filename_from_url($_GET['sec']);
	$sec = '../data/pages'.substr($sec, 0, strrpos($sec, '/'));
}
$newfile = getID().','.$_GET['page'];

if (file_exists($sec.'/'.$newfile)) {
	$timestamp = time();
	$newfile = $newfile.'-'.$timestamp;
}

if (!mkdir($sec.'/'.$newfile)) {
	include('error.inc.php');
	throw_error(locale('desc_error-restore',true), 'recyclebin.php?'.SID.csrf_protection_get());
}
$newfile = $newfile.'/01,Home';
if (!copy($file, $sec.'/'.$newfile)) {
	include('error.inc.php');
	throw_error(locale('desc_error-restore',true), 'recyclebin.php?'.SID.csrf_protection_get());
}
if (!unlink($file)) {
	include('error.inc.php');
	throw_error(locale('desc_error-restore',true), 'recyclebin.php?'.SID.csrf_protection_get());
}
include('cache.inc.php');
clear_cache('pages');
include('urlindex.inc.php');
generate_urlindex();
header('Location:pages.php?'.SID.csrf_protection_get());
?>
